@@ -5,7 +5,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Plack::Util;
 use Mojo::Message::Request;
 use Mojo::Message::Response;
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 use Scalar::Util 'weaken';
     
     ### ---
@@ -223,7 +223,8 @@ use Mojo::Base -base;
     }
     
     sub print {
-        shift->handler->(shift);
+        my ($self, $error) = @_;
+        $self->handler->($error);
     }
 
 ### ---
